@@ -622,8 +622,9 @@ class ObjectStorageContext(ObjectStorageContextFileMixin):
         """
         raise NotImplementedError()
 
+    @property
     @abstractmethod
-    def numCommitsOnWorkingBranch(self) -> int:
+    def commitsOnWorkingBranchCount(self) -> int:
         """Number of Commits on the Working Branch
 
         Get the number of commits on the __working__ branch
@@ -632,6 +633,7 @@ class ObjectStorageContext(ObjectStorageContextFileMixin):
         """
         raise NotImplementedError()
 
+    @property
     @abstractmethod
     def changesSinceLastCommit(self) -> ProjectModifiedTuple:
         """Changes Since Last Commit
@@ -720,7 +722,7 @@ class ObjectStorageContext(ObjectStorageContextFileMixin):
         raise NotImplementedError()
 
     @abstractmethod
-    def discardWorkingBranch(self) -> None:
+    def discardChangesSincePrevCommit(self) -> None:
         """Discard Working Branch
 
         Discard the working branch of the project to revert the changes made
