@@ -469,7 +469,7 @@ class GitLibMixin:
         # dynamic property and returns the currently checked out branch which
         # could be __working__. We need a reference to the 'master' branch
         # which should be the branch checked out at this point
-        checked = self.__checkedOutBranch
+        checkedOutBranch = self.__checkedOutBranch
 
         self._repo.checkout(makeRef(ATTUNE_WORKING_BRANCH))
         # Create squash commit
@@ -501,9 +501,9 @@ class GitLibMixin:
         # Reload the reference to the working branch
         working = self.__workingBranch
 
-        self._repo.checkout(checked.name)
-        checked.set_target(working.target)
-        self._repo.reset(checked.target, pygit2.GIT_RESET_HARD)
+        self._repo.checkout(checkedOutBranch.name)
+        checkedOutBranch.set_target(working.target)
+        self._repo.reset(checkedOutBranch.target, pygit2.GIT_RESET_HARD)
 
         # Delete the working branch. It will be recreated if there is a new
         # commit
@@ -515,18 +515,19 @@ class GitLibMixin:
         self._writeReadme(readmeContent)
         self.commit("Updated README.md")
 
-    def numCommitsOnWorkingBranch(self) -> int:
+    @property
+    def commitsOnWorkingBranchCount(self) -> int:
         if ATTUNE_WORKING_BRANCH not in self._repo.branches:
             return 0
 
-        working = self.__workingBranch
-        checkedOut = self.__checkedOutBranch
-        checkedLastCommit = next(self._repo.walk(checkedOut.target), None)
+        workingBranch = self.__workingBranch
+        checkedOutBranch = self.__checkedOutBranch
+        checkedLastCommit = next(self._repo.walk(checkedOutBranch.target), None)
 
         # Walk the commits till we find the previous common point
         commitsOnWorking = 0
-        for c in self._repo.walk(working.target):
-            if c.id == checkedLastCommit.id:
+        for commit in self._repo.walk(workingBranch.target):
+            if commit.id == checkedLastCommit.id:
                 break
             commitsOnWorking += 1
 
@@ -717,20 +718,22 @@ class GitLibMixin:
         if sourceBranch not in self.allBranches():
             raise ValueError(f"Branch {sourceBranch} does not exist")
 
-        checked = self.__checkedOutBranch
+        checkedOutBranch = self.__checkedOutBranch
         if ATTUNE_WORKING_BRANCH in self._repo.branches:
             working = self.__workingBranch
 
-            logger.debug(f"Merging branches {sourceBranch} to {checked.name}")
+            logger.debug(
+                f"Merging branches {sourceBranch} to {checkedOutBranch.name}"
+            )
 
-            if working.target != checked.target:
+            if working.target != checkedOutBranch.target:
                 raise RuntimeError(
                     "There are changes pending to be committed. Please commit "
                     "them before trying again"
                 )
 
         sourceBranchId = self._repo.branches[sourceBranch].target
-        checkedBranchId = checked.target
+        checkedBranchId = checkedOutBranch.target
 
         mergeAnalysis, _ = self._repo.merge_analysis(sourceBranchId)
         if mergeAnalysis & pygit2.GIT_MERGE_ANALYSIS_UP_TO_DATE:
@@ -739,8 +742,8 @@ class GitLibMixin:
 
         if mergeAnalysis & pygit2.GIT_MERGE_ANALYSIS_FASTFORWARD:
             logger.debug("Branch can be fast-forwarded")
-            # Fast-forward checked branch to source branch
-            checked.set_target(sourceBranchId)
+            # Fast-forward checkedOutBranch branch to source branch
+            checkedOutBranch.set_target(sourceBranchId)
 
         elif mergeAnalysis & pygit2.GIT_MERGE_ANALYSIS_NORMAL:
             """
@@ -775,16 +778,16 @@ class GitLibMixin:
         else:
             raise RuntimeError("Unknown Git merge analysis result")
 
-        checked = self.__checkedOutBranch
+        checkedOutBranch = self.__checkedOutBranch
         if ATTUNE_WORKING_BRANCH in self._repo.branches:
             # Fast-forward the working branch on top of the merged branch
             # We need to reload the branch references here
             working = self.__workingBranch
-            working.set_target(checked.target)
-        # The checked branch status will show the modified files from the pull
+            working.set_target(checkedOutBranch.target)
+        # The checkedOutBranch branch status will show the modified files from the pull
         # here as staged because they were not created on disk. This will create
         # those files
-        self._repo.reset(checked.target, pygit2.GIT_RESET_HARD)
+        self._repo.reset(checkedOutBranch.target, pygit2.GIT_RESET_HARD)
 
         # Check for project validation errors after merge
         try:
@@ -835,23 +838,23 @@ class GitLibMixin:
             # Reload all items
             self.reloadProject()
 
-    def renameProject(self, newName: str):
-        """
-        The user should not be able to rename when there is a __working__
-        branch present. This is because we want the user to be able to revert
-        and discard the changes on the __working__ branch. If rename is
-        reverted, the Attune DB and the project name committed to
-        `metadata.json` in the project will be out-of-sync
-        """
-        if ATTUNE_WORKING_BRANCH in self._repo.branches:
-            raise RuntimeError(
-                "There are changes pending to be committed. Please commit "
-                "them before trying again"
-            )
+    def diffCheckedOutToWorkingBranch(self) -> pygit2.Diff:
+        return self._repo.diff(
+            a=self.__checkedOutBranch.target, b=self.__workingBranch.target
+        )
 
-        metadata = self.metadata
-        metadata["name"] = newName
+    def getCommits(self) -> list[GitCommitTuple]:
+        for commit in self._repo.walk(self.__checkedOutBranch.target):
+            gitCommit = GitCommitTuple()
+            gitCommit.authorName = commit.author.name
+            gitCommit.authorEmail = commit.author.email
+            gitCommit.message = commit.message
+            gitCommit.timestamp = datetime.fromtimestamp(
+                commit.commit_time
+            ).strftime("%Y-%m-%d %H:%M:%S")
+            gitCommit.hash = commit.short_id
 
-        self.writeMetadata(metadata)
-        self.commit("Write metadata with new name")
-        self.squashAndMergeWorking(f"Renamed project to {newName}")
+            yield gitCommit
+
+    def freeGitDbResources(self) -> None:
+        self._repo.free()
