@@ -18,6 +18,7 @@ from attune_project_api.items.step_tuples.step_sql_oracle_tuple import (
     StepSqlOracleTuple,
 )
 from attune_project_api.migration import runMigrationsForStorageContext
+from .GitLibMixin import ATTUNE_WORKING_BRANCH
 from .GitLibMixin import GitLibMixin
 from ..Exceptions import ItemNotFoundError
 from ..Exceptions import ProjectIncorrectVersionError
@@ -35,6 +36,11 @@ from ..items.file_archive_tuples.file_tuple_constants import (
     FileArchiveTupleTypeEnum,
 )
 from ..migration import checkIfLibrarySupportsRevision
+from ..tuples.project_modified_tuple import ModifiedItemDetails
+from ..tuples.project_modified_tuple import ProjectModifiedTuple
+from ..tuples.project_modified_tuple import STAT_ADDED
+from ..tuples.project_modified_tuple import STAT_DELETED
+from ..tuples.project_modified_tuple import STAT_MODIFIED
 
 
 logger = logging.getLogger(__name__)
@@ -618,3 +624,128 @@ class GitObjectStorageContext(
         self.expungeItem(item)
         self.expireItem(item)
         self._cascadeDelete(item)
+
+    def discardChangesSincePrevCommit(self):
+        if ATTUNE_WORKING_BRANCH not in self._repo.branches:
+            raise Exception("There are no changes to discard")
+
+        self._repo.branches.delete(ATTUNE_WORKING_BRANCH)
+        self.reloadProject()
+
+    def renameProject(self, newName: str):
+        """
+        The user should not be able to rename when there is a __working__
+        branch present. This is because we want the user to be able to revert
+        and discard the changes on the __working__ branch. If rename is
+        reverted, the Attune DB and the project name committed to
+        `metadata.json` in the project will be out-of-sync
+        """
+        if ATTUNE_WORKING_BRANCH in self._repo.branches:
+            raise RuntimeError(
+                "There are changes pending to be committed. Please commit "
+                "them before trying again"
+            )
+
+        metadata = self.metadata
+        metadata["name"] = newName
+
+        self.writeMetadata(metadata)
+        self.commit("Write metadata with new name")
+        self.squashAndMergeWorking(f"Renamed project to {newName}")
+
+    @property
+    def changesSinceLastCommit(self) -> ProjectModifiedTuple:
+        changes = ProjectModifiedTuple()
+        changes.commitsOnWorkingBranch = self.commitsOnWorkingBranchCount
+
+        # Don't calculate the diff if __working__ does not have any commits
+        if changes.commitsOnWorkingBranch == 0:
+            return changes
+
+        # The keys of this dictionary correspond to folder names in the
+        # repository
+        changedItems = dict(
+            steps=defaultdict(lambda: None),
+            parameters=defaultdict(lambda: None),
+            files=defaultdict(lambda: None),
+        )
+
+        diff = self.diffCheckedOutToWorkingBranch()
+        for delta in diff.deltas:
+            change = delta.status_char()
+            fileName = delta.new_file.path
+
+            itemType, itemKey, *pathTail = fileName.split("/")
+            # We only include item modifications for now
+            # TODO: Expand this to include other changes
+            if itemType not in changedItems:
+                continue
+
+            modifiedFile = pathTail[-1]
+
+            if itemType == "steps":
+                itemGroup = ItemStorageGroupEnum.Step
+            elif itemType == "parameters":
+                itemGroup = ItemStorageGroupEnum.Parameter
+            elif itemType == "files":
+                itemGroup = ItemStorageGroupEnum.FileArchive
+            else:
+                raise NotImplementedError()
+
+            try:
+                item = self.getItem(itemGroup, itemKey)
+            except ItemNotFoundError:
+                changedItems[itemType][itemKey] = self._mergeItemChange(
+                    changedItems[itemType][itemKey],
+                    ModifiedItemDetails(
+                        key=itemKey,
+                        name=f"{{key:{itemKey}}}",
+                        changeStatus=change,
+                    ),
+                    modifiedFile,
+                )
+                continue
+            changedItems[itemType][itemKey] = self._mergeItemChange(
+                changedItems[itemType][itemKey],
+                ModifiedItemDetails(
+                    key=itemKey,
+                    name=item.name,
+                    changeStatus=change,
+                ),
+                modifiedFile,
+            )
+
+        changes.modifiedSteps = list(changedItems["steps"].values())
+        changes.modifiedFiles = list(changedItems["files"].values())
+        changes.modifiedParams = list(changedItems["parameters"].values())
+
+        return changes
+
+    def _mergeItemChange(
+        self,
+        prevChange: ModifiedItemDetails,
+        newChange: ModifiedItemDetails,
+        modifiedFile: str,
+    ) -> ModifiedItemDetails:
+        if prevChange is None:
+            # Removing/Adding files such as contents/ or comment.md from an item
+            # should be a modification change and not a deletion/add change
+            # Items are only deleted/added when their metadata.json and
+            # folder is deleted/added
+            if modifiedFile != "metadata.json" and newChange.changeStatus in (
+                STAT_DELETED,
+                STAT_ADDED,
+            ):
+                newChange.changeStatus = STAT_MODIFIED
+            return newChange
+
+        # We prefer the change to the metadata.json of an item
+        if modifiedFile == "metadata.json":
+            return newChange
+
+        if (
+            prevChange.changeStatus != STAT_DELETED
+            and newChange.changeStatus in (STAT_DELETED, STAT_ADDED)
+        ):
+            newChange.changeStatus = prevChange.changeStatus
+        return newChange
